@@ -1,12 +1,8 @@
 """Contains class for saving and loading text files."""
-from __future__ import unicode_literals  # at top of module
-from __future__ import print_function
 
 from io import StringIO
 from typing import Dict, List, Optional, Union, cast
 
-from past.builtins import basestring
-
 from . import data_utils
 from .base_data import BaseData
 
@@ -51,7 +47,7 @@ class TextData(BaseData):
             raise ValueError("Input data type is not string.")
 
         options = self._check_and_return_options(options)
-        super(TextData, self).__init__(input_file_path, data, options)
+        super().__init__(input_file_path, data, options)
 
         # 'Private' properties
         #  _data_formats: dict containing data_formats (key) and function
@@ -89,11 +85,7 @@ class TextData(BaseData):
 
     def _get_data_as_text(self, data: Union[str, List[str]]) -> List[str]:
         """Return data as text."""
-        if (
-            isinstance(data, list)
-            and len(data)
-            and isinstance(data[0], (str, basestring))
-        ):
+        if isinstance(data, list) and len(data) and isinstance(data[0], str):
             data = "".join(data)
         elif not isinstance(data, str) and data:
             raise ValueError(
@@ -152,5 +144,5 @@ class TextData(BaseData):
         :type options: dict
         :return: None
         """
-        super(TextData, self).reload(input_file_path, data, options)
+        super().reload(input_file_path, data, options)
         self.__init__(self.input_file_path, data, options)  # type: ignore
