@@ -1,8 +1,10 @@
 """Contains functions for the data labeler."""
+from __future__ import annotations
+
 import logging
 import os
 import warnings
-from typing import Any, Callable, Dict, List, Optional, Tuple, cast
+from typing import Any, Callable, Dict, cast
 
 import numpy as np
 import scipy
@@ -17,7 +19,7 @@ warnings.filterwarnings("ignore", category=UndefinedMetricWarning)
 logger = dp_logging.get_child_logger(__name__)
 
 
-def f1_report_dict_to_str(f1_report: Dict, label_names: List[str]) -> str:
+def f1_report_dict_to_str(f1_report: dict, label_names: list[str]) -> str:
     """
     Return the report string from the f1_report dict.
 
@@ -76,14 +78,14 @@ def f1_report_dict_to_str(f1_report: Dict, label_names: List[str]) -> str:
 
 
 def evaluate_accuracy(
-    predicted_entities_in_index: List[List[int]],
-    true_entities_in_index: List[List[int]],
+    predicted_entities_in_index: list[list[int]],
+    true_entities_in_index: list[list[int]],
     num_labels: int,
-    entity_rev_dict: Dict[int, str],
+    entity_rev_dict: dict[int, str],
     verbose: bool = True,
-    omitted_labels: Tuple[str, ...] = ("PAD", "UNKNOWN"),
-    confusion_matrix_file: str = None,
-) -> Tuple[float, Dict]:
+    omitted_labels: tuple[str, ...] = ("PAD", "UNKNOWN"),
+    confusion_matrix_file: str | None = None,
+) -> tuple[float, dict]:
     """
     Evaluate accuracy from comparing predicted labels with true labels.
 
@@ -125,7 +127,7 @@ def evaluate_accuracy(
     true_labels_flatten = np.hstack(true_labels_padded)  # type: ignore
     predicted_labels_flatten = np.hstack(predicted_entities_in_index)
 
-    all_labels: List[str] = []
+    all_labels: list[str] = []
     if entity_rev_dict:
         all_labels = [entity_rev_dict[key] for key in sorted(entity_rev_dict.keys())]
 
@@ -166,7 +168,7 @@ def evaluate_accuracy(
 
         conf_mat_pd.to_csv(confusion_matrix_file)
 
-    f1_report: Dict = cast(
+    f1_report: dict = cast(
         Dict,
         classification_report(
             conf_mat, labels=label_indexes, target_names=label_names, output_dict=True
@@ -212,9 +214,7 @@ def evaluate_accuracy(
     return f1, f1_report
 
 
-def get_tf_layer_index_from_name(
-    model: tf.keras.Model, layer_name: str
-) -> Optional[int]:
+def get_tf_layer_index_from_name(model: tf.keras.Model, layer_name: str) -> int | None:
     """
     Return the index of the layer given the layer name within a tf model.
 
@@ -247,7 +247,7 @@ def hide_tf_logger_warnings() -> None:
 
 
 def protected_register_keras_serializable(
-    package: str = "Custom", name: str = None
+    package: str = "Custom", name: str | None = None
 ) -> Callable:
     """
     Protect against already registered keras serializable layers.
@@ -317,11 +317,11 @@ class FBetaScore(tf.keras.metrics.Metric):
     def __init__(
         self,
         num_classes: int,
-        average: str = None,
+        average: str | None = None,
         beta: float = 1.0,
-        threshold: float = None,
+        threshold: float | None = None,
         name: str = "fbeta_score",
-        dtype: str = None,
+        dtype: str | None = None,
         **kwargs: Any,
     ) -> None:
         """Initialize FBetaScore class."""
@@ -367,7 +367,10 @@ class FBetaScore(tf.keras.metrics.Metric):
         self.weights_intermediate = _zero_wt_init("weights_intermediate")
 
     def update_state(
-        self, y_true: tf.Tensor, y_pred: tf.Tensor, sample_weight: tf.Tensor = None
+        self,
+        y_true: tf.Tensor,
+        y_pred: tf.Tensor,
+        sample_weight: tf.Tensor | None = None,
     ) -> None:
         """Update state."""
         if self.threshold is None:
@@ -381,9 +384,7 @@ class FBetaScore(tf.keras.metrics.Metric):
         y_true = tf.cast(y_true, self.dtype)
         y_pred = tf.cast(y_pred, self.dtype)
 
-        def _weighted_sum(
-            val: tf.Tensor, sample_weight: Optional[tf.Tensor]
-        ) -> tf.Tensor:
+        def _weighted_sum(val: tf.Tensor, sample_weight: tf.Tensor | None) -> tf.Tensor:
             if sample_weight is not None:
                 val = tf.math.multiply(val, tf.expand_dims(sample_weight, 1))
             return tf.reduce_sum(val, axis=self.axis)
@@ -422,7 +423,7 @@ class FBetaScore(tf.keras.metrics.Metric):
 
         return f1_score
 
-    def get_config(self) -> Dict:
+    def get_config(self) -> dict:
         """Return the serializable config of the metric."""
         config = {
             "num_classes": self.num_classes,
@@ -434,8 +435,8 @@ class FBetaScore(tf.keras.metrics.Metric):
         base_config = super().get_config()
         return {**base_config, **config}
 
-    def reset_states(self) -> None:
-        """Reset states."""
+    def reset_state(self) -> None:
+        """Reset state."""
         reset_value = tf.zeros(self.init_shape, dtype=self.dtype)
         tf.keras.backend.batch_set_value([(v, reset_value) for v in self.variables])
 
@@ -485,15 +486,15 @@ class F1Score(FBetaScore):
     def __init__(
         self,
         num_classes: int,
-        average: str = None,
-        threshold: float = None,
+        average: str | None = None,
+        threshold: float | None = None,
         name: str = "f1_score",
-        dtype: str = None,
+        dtype: str | None = None,
     ) -> None:
         """Initialize F1Score object."""
         super().__init__(num_classes, average, 1.0, threshold, name=name, dtype=dtype)
 
-    def get_config(self) -> Dict:
+    def get_config(self) -> dict:
         """Get configuration."""
         base_config = super().get_config()
         del base_config["beta"]
