@@ -439,7 +439,7 @@ class TestCSVDataClass(unittest.TestCase):
         for input_file in cls.input_file_names:
             # add StringIO
             buffer_info = input_file.copy()
-            with open(input_file["path"], "r", encoding=input_file["encoding"]) as fp:
+            with open(input_file["path"], encoding=input_file["encoding"]) as fp:
                 buffer_info["path"] = StringIO(fp.read())
             cls.buffer_list.append(buffer_info)
 
@@ -560,7 +560,7 @@ class TestCSVDataClass(unittest.TestCase):
             "`header` must be one of following: auto, "
             "none for no header, or a non-negative "
             "integer for the row that represents the "
-            "header \(0 based index\)",
+            r"header \(0 based index\)",
         ):
             csv_data = CSVData(filename, options=options)
             first_value = csv_data.data.loc[0][0]
@@ -572,7 +572,7 @@ class TestCSVDataClass(unittest.TestCase):
             "`header` must be one of following: auto, "
             "none for no header, or a non-negative "
             "integer for the row that represents the "
-            "header \(0 based index\)",
+            r"header \(0 based index\)",
         ):
             csv_data = CSVData(filename, options=options)
             first_value = csv_data.data.loc[0][0]
