@@ -428,7 +428,7 @@ class TestLoadedDataLabeler(unittest.TestCase):
         invalid_data = ["string", 1, None, dict()]
         print("\nInvalid Data Checks:")
         for data in invalid_data:
-            print("\tChecking data format: {}".format(str(type(data))))
+            print(f"\tChecking data format: {str(type(data))}")
             _invalid_check(data)
 
             # cannot predict dict
@@ -440,7 +440,7 @@ class TestLoadedDataLabeler(unittest.TestCase):
     def test_valid_fit_data_formats(self, mock_open, mock_load_model):
         def _valid_check(data):
             try:
-                print("\tChecking data format: {}".format(str(type(data))))
+                print(f"\tChecking data format: {str(type(data))}")
                 data = BaseDataLabeler._check_and_return_valid_data_format(
                     data, fit_or_predict="fit"
                 )
@@ -465,7 +465,7 @@ class TestLoadedDataLabeler(unittest.TestCase):
     def test_valid_predict_data_formats(self, mock_open, mock_load_model):
         def _valid_check(data):
             try:
-                print("\tChecking data format: {}".format(str(type(data))))
+                print(f"\tChecking data format: {str(type(data))}")
                 data = BaseDataLabeler._check_and_return_valid_data_format(
                     data, fit_or_predict="predict"
                 )
