@@ -1,28 +1,27 @@
 from dataprofiler.profilers.profiler_options import BaseOption
 
 
-class AbstractTestOptions():
-    
+class AbstractTestOptions:
+
     option_class = None
 
     @classmethod
     def validate_option_class(cls, *args, **kwargs):
         # Check option_class was set
         if cls.option_class is None:
-            raise ValueError("option_class class variable cannot be set to "
-                             "'None'")
+            raise ValueError("option_class class variable cannot be set to " "'None'")
 
         # Check option_class is correct type
         if not isinstance(cls.option_class, type):
-            raise ValueError("option_class class variable must be of type "
-                             "'type'")
+            raise ValueError("option_class class variable must be of type " "'type'")
 
         # Check option_class() is correct type
         options = cls.option_class(*args, **kwargs)
         if not isinstance(options, BaseOption):
-            raise ValueError("option_class class variable must create object "
-                             "of type 'BaseOption'")
-        
+            raise ValueError(
+                "option_class class variable must create object " "of type 'BaseOption'"
+            )
+
     @classmethod
     def get_options(cls, *args, **kwargs):
         cls.validate_option_class(*args, **kwargs)
@@ -35,15 +34,15 @@ class AbstractTestOptions():
 
     def test_init(self):
         raise NotImplementedError
- 
+
     def test_set_helper(self):
         raise NotImplementedError
- 
+
     def test_set(self):
         raise NotImplementedError
- 
+
     def test_validate_helper(self):
         raise NotImplementedError
- 
+
     def test_validate(self):
         raise NotImplementedError
