@@ -1,11 +1,8 @@
-from __future__ import print_function
-
 import unittest
 from unittest import mock
 
 import numpy as np
 import pandas as pd
-import six
 
 from dataprofiler.profilers import column_profile_compilers as col_pro_compilers
 from dataprofiler.profilers.profiler_options import (
@@ -444,8 +441,8 @@ class TestBaseProfileCompilerClass(unittest.TestCase):
             col_pro_compilers.BaseCompiler()
 
     def test_update_match_are_abstract(self):
-        six.assertCountEqual(
-            self, {"report"}, col_pro_compilers.BaseCompiler.__abstractmethods__
+        self.assertCountEqual(
+            {"report"}, col_pro_compilers.BaseCompiler.__abstractmethods__
         )
 
 
